@@ -166,6 +166,11 @@ GC WinGC;
 int CarrierOn = FALSE;
 int screen;
 
+/* 0.12 themes stuff: */
+
+/*#define THDIR "/usr/local/share/AScd"*/
+char theme[60];
+
 /* everything dealing with the hardware volume: */
 
 #define MAX_VOL 255
@@ -209,9 +214,11 @@ unsigned int panel = 0;
 
 void Help() 
 {
+#ifdef WMK
+    fprintf(stderr, "ascd %s [+WINGs module] (c) 1999 Rob Malda and Denis Bourez\n", VERSION);
+#else
     fprintf(stderr, "ascd %s (c) 1999 Rob Malda and Denis Bourez\n", VERSION);
-    fprintf(stderr, "Primary web site: http://worldserver.oleane.com/rsn/\n\n");
-
+#endif
     fprintf(stderr, "Usage:  ascd [-options ...] where the options are:\n\n");
 
     fprintf(stderr, "-version                 Display the version numbers and exit\n");
@@ -225,6 +232,7 @@ void Help()
     fprintf(stderr, "+/-B                     Turn on/off Blind mode (no counters updates)\n");
     fprintf(stderr, "+/-ia                    Apply/Ignore 'avoid' tags in WorkMan database\n"),
     fprintf(stderr, "+/-up                    All messages in uppercase?\n");
+    fprintf(stderr, "-theme value             Select the visual theme (in %s)\n", THDIR);
     fprintf(stderr, "-xf                      Launch XfAscd with middle click on counter\n");
     fprintf(stderr, "-minvolume value         Minimum volume\n");
     fprintf(stderr, "-maxvolume value         Maximum volume\n");
@@ -234,9 +242,7 @@ void Help()
     fprintf(stderr, "-device device_driver    CDROM drive device\n");
     fprintf(stderr, "-showtitle               Turn on Song Title Scrolling\n");
     fprintf(stderr, "-showartist              Show artist name when scrolling song title\n");
-    fprintf(stderr, "-save                    Save settings and exit. Should be *last* command.\n");
-
-    fprintf(stderr,"\nPlease check the ascd(1) man page for more details.\n\n");
+    fprintf(stderr, "-save                    Save settings and exit. Should be *last* command.\n\n");
     exit(1);
 } 
 
@@ -280,6 +286,11 @@ void ParseCmdLine(int argc, char *argv[]) {
 		strcpy(cd_device, argv[i]);
 	    }
 
+	    else if (strcmp(Argument + 1, "theme") == 0) {
+		if(++i >= argc) SHelp();
+		strcpy(theme, argv[i]);
+	    }
+
 	    else if ((strcmp(Argument + 1, "f") == 0) || (strcmp(Argument + 1, "fg") == 0)) {
 		if(++i >= argc) SHelp();
 		strcpy(led_color, "X c ");
@@ -420,6 +431,7 @@ void load_rc_file(int mx)
 		if (!mx) {
 #ifndef NO_D_DEVICE
 		    if (strncmp(st, "CD_DEVICE=", 10) == 0) strcpy(cd_device, st + 10);
+		    else if (strncmp(st, "THEME=", 6) == 0) strcpy(theme, st + 6);
 		    else if (strncmp(st, "AUTOREPEAT=", 11) == 0) autorepeat = atoi(st + 11);
 #else
 		    if (strncmp(st, "AUTOREPEAT=", 11) == 0) autorepeat = atoi(st + 11);
@@ -468,6 +480,7 @@ void save_rc_file()
 #ifndef NO_D_DEVICE
 	    fprintf(out, "CD_DEVICE=%s\n", cd_device);
 #endif	   
+	    fprintf(out, "THEME=%s\n", theme);
             fprintf(out, "AUTOREPEAT=%d\n", autorepeat);
             fprintf(out, "AUTOPLAY=%d\n", autoplay);
             fprintf(out, "CUE_TIME=%d\n", cue_time);
@@ -711,7 +724,7 @@ void cdplayer_mouse_events(XEvent Event)
 	}
 
 	RedrawWindow(&backXPM);
-    } else {
+    } else if (Event.xbutton.y > 40) {
 	/* the bottow row */
 	if (Event.xbutton.x <= 18) {
 	    /* PAUSE or FADE */
@@ -773,6 +786,7 @@ Pixel GetColor(char *ColorName)
 {
     XColor Color;
     XWindowAttributes Attributes;
+
     XGetWindowAttributes(Disp,Root,&Attributes);
     Color.pixel = 0;
 
@@ -786,127 +800,117 @@ Pixel GetColor(char *ColorName)
 
 void GetXPM(char *foreground, char *background) 
 {
+    char txt[256];
     XWindowAttributes Attributes;
     int Ret;
 
-    /* The pixmap definition files: */
-
-#include "pixmaps/default/background.xpm"
-#include "pixmaps/default/eject.xpm"
-#include "pixmaps/default/fwd.xpm"
-#include "pixmaps/default/pause.xpm"
-#include "pixmaps/default/pause_on.xpm"
-#include "pixmaps/default/play.xpm"
-#include "pixmaps/default/play_on.xpm"
-#include "pixmaps/default/rew.xpm"
-#include "pixmaps/default/stop.xpm"
-#include "pixmaps/default/digits.xpm"
-#include "pixmaps/default/rdigits.xpm"
-#include "pixmaps/default/bar.xpm"
-
-#include "pixmaps/default/lstart.xpm"
-#include "pixmaps/default/lend.xpm"
-#include "pixmaps/default/lgo.xpm"
-#include "pixmaps/default/lgo_on.xpm"
-#include "pixmaps/default/fade.xpm"
-#include "pixmaps/default/intro.xpm"
-#include "pixmaps/default/intro_on.xpm"
-#include "pixmaps/default/quit.xpm"
-
     XGetWindowAttributes(Disp,Root,&Attributes);
 
     /* background: */
 
-    backXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, background_xpm, &backXPM.pixmap,
-				  &backXPM.mask, &backXPM.attributes);
+    sprintf(txt, "%s/%s/background.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &backXPM.pixmap,
+			      &backXPM.mask, &backXPM.attributes);
 
     /* buttons: */
 
     fwdXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, fwd_xpm, &fwdXPM.pixmap,
-				  &fwdXPM.mask, &fwdXPM.attributes);
+    sprintf(txt, "%s/%s/fwd.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &fwdXPM.pixmap,
+			      &fwdXPM.mask, &fwdXPM.attributes);
     
     rewXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, rew_xpm, &rewXPM.pixmap,
+    sprintf(txt, "%s/%s/rew.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &rewXPM.pixmap,
 				  &rewXPM.mask, &rewXPM.attributes);
 
-
     playXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, play_xpm, &playXPM.pixmap,
+    sprintf(txt, "%s/%s/play.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &playXPM.pixmap,
 				  &playXPM.mask, &playXPM.attributes);
 
     play_onXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, play_on_xpm, &play_onXPM.pixmap,
+    sprintf(txt, "%s/%s/play_on.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &play_onXPM.pixmap,
 				  &play_onXPM.mask, &play_onXPM.attributes);
 
     pauseXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, pause_xpm, &pauseXPM.pixmap,
+    sprintf(txt, "%s/%s/pause.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &pauseXPM.pixmap,
 				  &pauseXPM.mask, &pauseXPM.attributes);
 
     pause_onXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, pause_on_xpm, &pause_onXPM.pixmap,
+    sprintf(txt, "%s/%s/pause_on.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &pause_onXPM.pixmap,
 				  &pause_onXPM.mask, &pause_onXPM.attributes);
 
     ejectXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, eject_xpm, &ejectXPM.pixmap,
+    sprintf(txt, "%s/%s/eject.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &ejectXPM.pixmap,
 				  &ejectXPM.mask, &ejectXPM.attributes);
 
     stopXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, stop_xpm, &stopXPM.pixmap,
-				  &stopXPM.mask, &stopXPM.attributes);
+    sprintf(txt, "%s/%s/stop.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &stopXPM.pixmap,
+			      &stopXPM.mask, &stopXPM.attributes);
 
     lstartXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, lstart_xpm, &lstartXPM.pixmap,
+    sprintf(txt, "%s/%s/lstart.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &lstartXPM.pixmap,
 				  &lstartXPM.mask, &lstartXPM.attributes);
 
     lendXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, lend_xpm, &lendXPM.pixmap,
+    sprintf(txt, "%s/%s/lend.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &lendXPM.pixmap,
 				  &lendXPM.mask, &lendXPM.attributes);
 
     lgoXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, lgo_xpm, &lgoXPM.pixmap,
+    sprintf(txt, "%s/%s/lgo.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &lgoXPM.pixmap,
 				  &lgoXPM.mask, &lgoXPM.attributes);
 
     lgo_onXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, lgo_on_xpm, &lgo_onXPM.pixmap,
+    sprintf(txt, "%s/%s/lgo_on.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &lgo_onXPM.pixmap,
 				  &lgo_onXPM.mask, &lgo_onXPM.attributes);
 
     fadeXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, fade_xpm, &fadeXPM.pixmap,
+    sprintf(txt, "%s/%s/fade.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &fadeXPM.pixmap,
 				  &fadeXPM.mask, &fadeXPM.attributes);
 
     introXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, intro_xpm, &introXPM.pixmap,
+    sprintf(txt, "%s/%s/intro.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &introXPM.pixmap,
 				  &introXPM.mask, &introXPM.attributes);
 
     intro_onXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, intro_on_xpm, &intro_onXPM.pixmap,
+    sprintf(txt, "%s/%s/intro_on.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &intro_onXPM.pixmap,
 				  &intro_onXPM.mask, &intro_onXPM.attributes);
 
     quitXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, quit_xpm, &quitXPM.pixmap,
+    sprintf(txt, "%s/%s/quit.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &quitXPM.pixmap,
 				  &quitXPM.mask, &quitXPM.attributes);
 
     alphaXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, digits_xpm, &alphaXPM.pixmap,
+    sprintf(txt, "%s/%s/digits.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &alphaXPM.pixmap,
 				  &alphaXPM.mask, &alphaXPM.attributes);
 
     ralphaXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, rdigits_xpm, &ralphaXPM.pixmap,
+    sprintf(txt, "%s/%s/rdigits.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &ralphaXPM.pixmap,
 				  &ralphaXPM.mask, &ralphaXPM.attributes);
 
     barXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, bar_xpm, &barXPM.pixmap,
-				  &barXPM.mask, &barXPM.attributes);
-
-
-    barXPM.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
-    Ret = XpmCreatePixmapFromData(Disp, Root, bar_xpm, &barXPM.pixmap,
+    sprintf(txt, "%s/%s/bar.xpm", THDIR, theme);
+    Ret = XpmReadFileToPixmap(Disp, Root, txt, &barXPM.pixmap,
 				  &barXPM.mask, &barXPM.attributes);
 
     if (Ret != XpmSuccess) {
-	fprintf(stderr, "ascd: can't initialize the background and/or buttons pixmaps.\nCauses can be:\n- problem(s) in the files\n- a non existing color in fore/background colors definition\n- not enough free color cells\n\n");
+	fprintf(stderr, "ascd: can't load the background and/or buttons pixmaps.\nCauses can be:\n- problem(s) in the files\n- a non existing color in fore/background colors definition\n- not enough free color cells\n\n");
 	exit(1);
     }
 } 
@@ -1682,6 +1686,7 @@ int main(int argc, char *argv[])
 #endif
 
     strcpy(led_text, "");
+    strcpy(theme, "default");
     
     /* prepares the LED colors variables: */
     
