@@ -92,6 +92,7 @@ WMWidget *db_tlabel;
 /* the 'about' window */
 
 WMWindow *aboutwin;
+WMWidget *about_theme;
 
 /* misc */
 
@@ -178,6 +179,11 @@ void track_select(WMWidget *self, void *data) {
     if (cur_cdmode == WM_CDM_STOPPED) cd_control(PLAY);
 }
 
+void theme_select(WMWidget *self, void *data) {
+    strcpy(theme, WMGetPopUpButtonItem(self, WMGetPopUpButtonSelectedItem(self)   )   );
+    GetXPM(led_color, led_bgcolor);
+}
+
 void mode1_cb(WMWidget *self, void *data) {
     if (WMGetButtonSelected(b_mode1)) {
 	WMSetButtonSelected((b_mode2), FALSE);
@@ -292,14 +298,14 @@ void volume_cb(WMWidget *self, void *data) {
 void create_about_window(WMScreen *scr) {
     char txt[256];
     WMWidget *fr, *fr2, *fr3, *fr4;
-    WMWidget *lb1, *lb2, *lb3, *lb4;
+    WMWidget *lb1, *lb2, *lb3, *lb4, *lb5, *lb6;
     WMWidget *infos;
     WMFont *font;
 
     aboutwin = WMCreateWindow(scr, "AScd-about");
     WMSetWindowCloseAction(aboutwin, close_aboutwin, NULL);
     WMSetWindowTitle(aboutwin, "Info");
-    WMResizeWidget(aboutwin, 340, 100);
+    WMResizeWidget(aboutwin, 340, 125);
 
     lb1 = WMCreateLabel(aboutwin);
     WMResizeWidget(lb1, 35, 20);
@@ -325,28 +331,72 @@ void create_about_window(WMScreen *scr) {
 	WMSetLabelFont(lb3, font);
 	WMReleaseFont(font);
     }
-    sprintf(txt, "(c) 1997-1999 Denis Bourez and Rob Malda\nContact: denis@rsn.fdn.fr\nURL: http://worldserver.oleane.com/rsn/ascd-en.html");
+    sprintf(txt, "(c) 1996-1999 Denis Bourez and Rob Malda\nContact: denis@rsn.fdn.fr\nURL: http://worldserver.oleane.com/rsn/ascd-en.html");
     WMSetLabelText(lb3, txt);
 
+    lb5 = WMCreateLabel(aboutwin);
+    WMResizeWidget(lb5, 60, 20);
+    WMMoveWidget(lb5, 50, 70);
+    font = WMBoldSystemFontOfSize(scr, 10);
+    if (font) {
+	WMSetLabelFont(lb5, font);
+	WMReleaseFont(font);
+    }
+    WMSetLabelText(lb5, "Control:");
+
     lb4 = WMCreateLabel(aboutwin);
-    WMResizeWidget(lb4, 280, 20);
-    WMMoveWidget(lb4, 50, 70);
+    WMResizeWidget(lb4, 240, 20);
+    WMMoveWidget(lb4, 110, 70);
     font = WMSystemFontOfSize(scr, 10);
     if (font) {
 	WMSetLabelFont(lb4, font);
 	WMReleaseFont(font);
     }
-    sprintf(txt, "Subsystems: CD Control %s + %s", cd_control_version(),  wm_libver_string());
+    sprintf(txt, "CD Control %s + %s", cd_control_version(),  wm_libver_string());
     WMSetLabelText(lb4, txt);
 
+    lb6 = WMCreateLabel(aboutwin);
+    WMResizeWidget(lb6, 70, 20);
+    WMMoveWidget(lb6, 50, 89);
+    font = WMBoldSystemFontOfSize(scr, 10);
+    if (font) {
+	WMSetLabelFont(lb6, font);
+	WMReleaseFont(font);
+    }
+    WMSetLabelText(lb6, "Theme:");
+
+    about_theme = WMCreateLabel(aboutwin);
+    WMResizeWidget(about_theme, 240, 40);
+    WMMoveWidget(about_theme, 110, 85);
+    font = WMSystemFontOfSize(scr, 10);
+    if (font) {
+	WMSetLabelFont(about_theme, font);
+	WMReleaseFont(font);
+    }
+    WMSetLabelText(about_theme, "A\nB");
+
     WMRealizeWidget(aboutwin);
 }
 
 void about_window(WMScreen *scr) {
     int i;
-    char txt[127];
+    char txt[256];
+    char txt2[256];
+    FILE *in;
 
     if (! about_en_vue) {
+	sprintf(txt, "%s/%s/Theme", THDIR, theme);
+	if (in = fopen(txt, "r")) {
+	    fgets(txt, 256, in);
+	    fgets(txt2, 256, in);
+	    txt2[strlen(txt2) - 1] = 0;
+	    strcat(txt, txt2);
+	    WMSetLabelText(about_theme, txt);
+	    fclose(in);
+	} else {
+	    WMSetLabelText(about_theme, "(visual theme info file not found)");
+	}
+
 	WMRealizeWidget(aboutwin);
 	WMMapSubwidgets(aboutwin);
 	WMMapWidget(aboutwin);
@@ -606,7 +656,7 @@ void create_big_window(WMScreen *scr) {
 
     lb6 = WMCreateLabel(win);
     WMResizeWidget(lb6, 80, 20);
-    WMMoveWidget(lb6, 20, 155);
+    WMMoveWidget(lb6, 15, 155);
     WMSetLabelText(lb6, "CD Device:");
 
     b_device = WMCreateTextField(win);
@@ -617,7 +667,7 @@ void create_big_window(WMScreen *scr) {
     fr3 = WMCreateFrame(win);
     WMMoveWidget(fr3, 130, 80);
     WMResizeWidget(fr3, 180, 125);
-    WMSetFrameTitle(fr3, "Misc:");
+    WMSetFrameTitle(fr3, "Display:");
 
     b_scroll = WMCreateButton(win, WBTSwitch);
     WMMoveWidget(b_scroll, 140, 95);
@@ -637,63 +687,71 @@ void create_big_window(WMScreen *scr) {
     WMSetButtonText(b_upper, "force uppercase");
     WMSetButtonAction(b_upper, upper_cb, NULL);
 
-    lb2 = WMCreateLabel(win);
-    WMResizeWidget(lb2, 70, 20);
-    WMMoveWidget(lb2, 140, 175);
-    WMSetLabelText(lb2, "Cue Time");
+    lb4 = WMCreateLabel(win);
+    WMResizeWidget(lb4, 130, 20);
+    WMMoveWidget(lb4, 135, 155);
+    WMSetLabelText(lb4, "Visual Theme:");
 
-    b_cuetime = WMCreateTextField(win);
-    WMResizeWidget(b_cuetime, 25, 20);
-    WMMoveWidget(b_cuetime, 205, 175);
+    pop2 = WMCreatePopUpButton(win);
+    WMResizeWidget(pop2, 160, 20);
+    WMMoveWidget(pop2, 140, 175);
+    /*WMSetPopUpButtonPullsDown(pop2, True);*/
+    WMSetPopUpButtonText(pop2, theme);
+    WMAddPopUpButtonItem(pop2, "1");
+    WMSetPopUpButtonAction(pop2, theme_select, NULL); 
 
-    lb3 = WMCreateLabel(win);
-    WMResizeWidget(lb3, 33, 20);
-    WMMoveWidget(lb3, 238, 175);
-    WMSetLabelText(lb3, "Fade");
-
-    b_fadestep = WMCreateTextField(win);
-    WMResizeWidget(b_fadestep, 25, 20);
-    WMMoveWidget(b_fadestep, 275, 175);
 
     /* the volume */
 
     fr4 = WMCreateFrame(win);
     WMMoveWidget(fr4, 10, 210);
     WMResizeWidget(fr4, 300, 75);
-    WMSetFrameTitle(fr4, "Volume:");
-
-    lb4 = WMCreateLabel(win);
-    WMResizeWidget(lb4, 35, 20);
-    WMMoveWidget(lb4, 20, 230);
-    WMSetLabelText(lb4, "From");
+    WMSetFrameTitle(fr4, "Volume & Misc:");
 
     b_minvol = WMCreateTextField(win);
-    WMResizeWidget(b_minvol, 40, 20);
-    WMMoveWidget(b_minvol, 60, 230);
+    WMResizeWidget(b_minvol, 30, 20);
+    WMMoveWidget(b_minvol, 20, 230);
 
-    lb5 = WMCreateLabel(win);
-    WMResizeWidget(lb5, 30, 20);
-    WMMoveWidget(lb5, 103, 230);
-    WMSetLabelText(lb5, "to");
+    b_volume = WMCreateSlider(win);
+    WMResizeWidget(b_volume, 220, 20);
+    WMMoveWidget(b_volume, 50, 230);
+    WMSetSliderKnobThickness(b_volume, 22);
+    WMSetSliderAction(b_volume, volume_cb, NULL);
 
     b_maxvol = WMCreateTextField(win);
-    WMResizeWidget(b_maxvol, 40, 20);
-    WMMoveWidget(b_maxvol, 123, 230);
+    WMResizeWidget(b_maxvol, 30, 20);
+    WMMoveWidget(b_maxvol, 270, 230);
 
     lb1 = WMCreateLabel(win);
     WMResizeWidget(lb1, 40, 20);
-    WMMoveWidget(lb1, 215, 230);
+    WMMoveWidget(lb1, 15, 260);
     WMSetLabelText(lb1, "Muted");
 
     b_mutedvol = WMCreateTextField(win);
-    WMResizeWidget(b_mutedvol, 40, 20);
-    WMMoveWidget(b_mutedvol, 260, 230);
+    WMResizeWidget(b_mutedvol, 30, 20);
+    WMMoveWidget(b_mutedvol, 65, 260);
+
+    lb2 = WMCreateLabel(win);
+    WMResizeWidget(lb2, 70, 20);
+    WMMoveWidget(lb2, 105, 260);
+    WMSetLabelText(lb2, "Cue Time");
+
+    b_cuetime = WMCreateTextField(win);
+    WMResizeWidget(b_cuetime, 25, 20);
+    WMMoveWidget(b_cuetime, 180, 260);
+
+    lb3 = WMCreateLabel(win);
+    WMResizeWidget(lb3, 33, 20);
+    WMMoveWidget(lb3, 225, 260);
+    WMSetLabelText(lb3, "Fade");
+
+    b_fadestep = WMCreateTextField(win);
+    WMResizeWidget(b_fadestep, 25, 20);
+    WMMoveWidget(b_fadestep, 275, 260);
+
+
+
 
-    b_volume = WMCreateSlider(win);
-    WMResizeWidget(b_volume, 280, 16);
-    WMMoveWidget(b_volume, 20, 257);
-    WMSetSliderKnobThickness(b_volume, 22);
-    WMSetSliderAction(b_volume, volume_cb, NULL);
 
     /* the counter modes */
 
@@ -717,7 +775,7 @@ void create_big_window(WMScreen *scr) {
     b_mode3 = WMCreateButton(win, WBTRadio);
     WMMoveWidget(b_mode3, 90, 305);
     WMResizeWidget(b_mode3, 85, 20);
-    WMSetButtonText(b_mode3, "Ellapsed");
+    WMSetButtonText(b_mode3, "Elapsed");
     WMSetButtonAction(b_mode3, mode3_cb, NULL);
 
     b_mode4 = WMCreateButton(win, WBTRadio);
@@ -737,7 +795,7 @@ void create_big_window(WMScreen *scr) {
     b_about = WMCreateButton(win, 0);
     WMResizeWidget(b_about, 50, 25);
     WMMoveWidget(b_about, 205, 295);
-    WMSetButtonText(b_about, "About");
+    WMSetButtonText(b_about, "Info");
     WMSetButtonAction(b_about, about_cb, NULL);
 
     b_save = WMCreateButton(win, 0);
@@ -819,6 +877,7 @@ void big_window(WMScreen *scr) {
     int i;
     char txt[127];
     char txt2[127];
+    FILE *in;
 
     if (! en_vue) {
 
@@ -845,6 +904,9 @@ void big_window(WMScreen *scr) {
 	    WMRemovePopUpButtonItem(pop, i);
 	}
 
+	for (i = WMGetPopUpButtonNumberOfItems(pop2); i >= 0; i --) {
+	    WMRemovePopUpButtonItem(pop2, i);
+	}
 
 	if (cd->artist != NULL) {
 	    strcpy(txt, cd->artist);
@@ -870,7 +932,16 @@ void big_window(WMScreen *scr) {
 	    if (cd->trk[i].songname != NULL) strcat(txt,  cd->trk[i].songname);
 	    WMAddPopUpButtonItem(pop, txt);
 	}
-	
+
+	sprintf(txt, "%s/.dir", THDIR);
+	if (in = fopen(txt, "r")) {
+	    while (fgets(txt, 255,in)) {
+		txt[strlen(txt) - 1] = 0;
+		WMAddPopUpButtonItem(pop2, txt);
+	    }
+	    fclose(in);
+	}
+
 	if (cd->trk[cur_track - 1].songname != NULL) {
 	    sprintf(txt, "%s", cd->trk[cur_track - 1].songname);
 	    if (strcmp(txt, "") == 0) sprintf(txt, "Track %d", cur_track);
